var R = require('ramda');
var gulp = require('gulp');
var run_sequence = require('run-sequence');
var path = require('path');
var fs = require('fs');
var dependencies = require(__dirname + '/package.json').dependencies;
var config = require(__dirname + '/src/config');
var browserSync = require('browser-sync').create();
var camelcase = require('camelcase');

// Load plugins
var gulpRegex = /^gulp-/;
var toName = R.pipe(
    R.replace(gulpRegex, ''),
    camelcase
);
var loadPlugins = R.pipe(
    R.keys,
    R.filter(R.test(gulpRegex)),
    R.map(function(moduleName) {
        return [toName(moduleName), require(moduleName)];
    }),
    R.fromPairs
);
var plugins = loadPlugins(dependencies);

// Load build tasks
var requireTask = function(name) {
    return require(__dirname + '/src/tasks/' + name)(gulp, plugins, config.globs, config.project_info, config.scripts_entry, config.views_entry, browserSync);
};
var loadTasks = R.pipe(
    R.map(R.replace('.js', '')),
    R.map(function(taskName) {
        return [taskName, requireTask(taskName)];
    }),
    R.fromPairs
);
var tasksList = fs.readdirSync(__dirname + '/src/tasks/');
var tasks = loadTasks(tasksList);

module.exports = tasks;
