var fs = require('fs-extra');
var path = require('path');
var project_info = fs.readJsonSync(process.cwd() + '/feds.json');
var _ = require('lodash');

function getPortForPath(path) {
    var p = 0;
    for (var x = 0; x < path.length; x++) p += path.charCodeAt(x);
    return p;
}

project_info.sources.components = project_info.sources.components || project_info.sources.scripts.replace(/scripts/gi, 'components');

module.exports.scripts_entry = require(process.cwd() + '/feds/config.webpack_entry.js');
module.exports.views_entry = require(process.cwd() + '/feds/config.views.js');
module.exports.project_info = project_info;
module.exports.globs = {
    ports: {
        static_server: getPortForPath(__dirname),
        ui: getPortForPath(__dirname) + 1,
        docs: getPortForPath(__dirname) + 2,
    },
    assets: {
        fonts: {
            what: path.join(project_info.sources.fonts, '*.{ttf,otf,woff2,woff,svg}'),
            where: path.join(project_info.destinations.base_dir, project_info.destinations.fonts)
        },
        public: {
            what: path.join(project_info.sources.public, '**/*.*'),
            where: project_info.destinations.base_dir
        },
    },
    styles: {
        compile: path.join(project_info.sources.styles, '!(injected).scss'),
        watch: (project_info.sources.app + '{' + [
            path.relative(project_info.sources.app, project_info.sources.views),
            path.relative(project_info.sources.app, project_info.sources.styles)
        ].join('/,') + '/}**/*.scss').replace(/\/{1,3}/gi, '\/'),
        inject: {
            what: (project_info.sources.app + '{' + [
                path.relative(project_info.sources.app, project_info.sources.views),
                path.relative(project_info.sources.app, project_info.sources.styles)
            ].join('/,') + '/}**/!(components)/**/!(_)*.scss').replace(/\/{1,3}/gi, '\/'),
            where: project_info.sources.styles
        },
        dest: path.join(project_info.destinations.base_dir, project_info.destinations.styles)
    },
    scripts: {
        compile: (project_info.sources.app + '/{' + [
            path.relative(project_info.sources.app, project_info.sources.pages + '/**/!(_)*.js'),
            path.relative(project_info.sources.app, project_info.sources.scripts) + '/{pages/*.js,standalone/*.js,*.js}',
        ].join(',') + '}').replace(/\/\//gi, '/'),
        watch: project_info.sources.app + '/!(styles|fonts|images)/**/*.js',
        inject: {
            what: [
                '!' + project_info.sources.app + '/views/widgets/from-renderer/components/**',
                (project_info.sources.views + '{' + [
                    path.relative(project_info.sources.views, project_info.sources.elements),
                    path.relative(project_info.sources.views, project_info.sources.widgets),
                    path.relative(project_info.sources.views, project_info.sources.components),
                ].join('/,') + '/}**/!(components)/**/!(_)*.js').replace(/\/{1,3}/gi, '\/')
            ],
            where: path.join(project_info.sources.scripts, 'libs/')
        },
        dest: path.join(project_info.destinations.base_dir, project_info.destinations.scripts)
    },
    views: {
        compile: path.join(project_info.sources.pages, '**/*.jade'),
        watch: [
            path.join(project_info.sources.app, '**/*.jade'),
            path.join(process.cwd(), 'content.json'),
        ],
        inject: {
            what: [
                (project_info.sources.views + '{' + [
                    path.relative(project_info.sources.views, project_info.sources.elements),
                    path.relative(project_info.sources.views, project_info.sources.widgets),
                //path.relative(project_info.sources.views, project_info.sources.components),
                ].join('/,') + '/}**/!(_)*.jade').replace(/\/{1,3}/gi, '\/'),
                '!**/components/**/*.jade',
            ],
            where: project_info.sources.layouts
        },
        dest: path.join(process.cwd(), project_info.destinations.views_static)
    },
    images: {
        compile: path.join(project_info.sources.images, '**/*.{jpg,png,gif,svg}'),
        watch: path.join(project_info.sources.images, '**/*.{jpg,png,gif,svg}'),
        dest: path.join(project_info.destinations.base_dir, project_info.destinations.images)
    }
};
