require('es6-promise').polyfill();

module.exports = function(gulp, plugins, globs, project_info, scripts_entry, views_entry, browserSync) {

    var path = require('path'),
        run_sequence = require('run-sequence'),
        release = process.argv.indexOf('--release') !== -1;

    return {
        compile: function() {
            return gulp.src(globs.styles.compile)
                .pipe(plugins.plumber())
                .pipe(plugins.if(!release, plugins.sourcemaps.init()))
                .pipe(plugins.sass())
                .on('error', function(err) {
                    plugins.util.log(err);
                    this.emit('end');
                })
                .pipe(plugins.postcss([require('autoprefixer'), require('lost')]))
                .pipe(plugins.if(release, plugins.csso()))
                .pipe(plugins.if(!release, plugins.sourcemaps.write()))
                .pipe(gulp.dest(globs.styles.dest))
                .on('error', plugins.util.log)
                .pipe(browserSync.stream({
                    match: '**/*.css'
                }));
        },
        lessCompile: function() {
            return gulp.src([path.join(project_info.sources.styles, 'less', '*style*.less'), ])
                .pipe(plugins.plumber())
                .pipe(plugins.if(!release, plugins.sourcemaps.init()))
                .pipe(plugins.less())
                .on('error', function(err) {
                    plugins.util.log(err);
                    this.emit('end');
                })
                .pipe(plugins.postcss([require('autoprefixer')]))
                .pipe(plugins.if(release, plugins.csso()))
                .pipe(plugins.if(!release, plugins.sourcemaps.write()))
                .pipe(gulp.dest(globs.styles.dest))
                .on('error', plugins.util.log)
                .pipe(browserSync.stream({
                    match: '**/*.css'
                }));
        },
        inject: function() {
            var files_to_inject = gulp.src(globs.styles.inject.what, {
                read: false
            });

            return gulp.src(path.join(globs.styles.inject.where, 'injected.scss'))
                .pipe(plugins.inject(files_to_inject, {
                    starttag: '// inject:{{ext}}',
                    endtag: '// endinject',
                    relative: true,
                    transform: function(filepath) {
                        return '@import \'' + filepath + '\';';
                    }
                }))
                .pipe(gulp.dest(globs.styles.inject.where));
        }
    };

};
