module.exports = function(gulp, plugins, globs, project_info, scripts_entry, views_entry, browserSync) {

	var fse = require('fs-extra');
	var path = require('path');
	var run_sequence = require('run-sequence');
	var merge = require('merge-stream');
	var rename = require('gulp-rename');
	var release = process.argv.indexOf('--release') !== -1;
	var views = views_entry;
	var R = require('ramda');

	try {
		var tr = fse.readJsonSync(path.join(process.cwd(), 'translations.json'));
	} catch (e) {
		// no translations file, return noop
		return {inject: function() {}, compileStatic: function() {}}
	}

	var templateLocals = {
		pkg: fse.readJsonSync(path.join(process.cwd(), 'package.json')),
		tr: R.map(R.prop(tr.languages[0]), tr.keys),
		lang: tr.languages[0]
	};

	return {
		inject: function() {
			var files_to_inject = gulp.src(globs.views.inject.what, {
				read: false
			});

			return console.log.bind(console), gulp.src(path.join(globs.views.inject.where, 'injected.jade'))
				.pipe(plugins.inject(files_to_inject, {
					starttag: '//- inject:{{ext}}',
					endtag: '//- endinject',
					relative: true,
					transform: function(filepath) {
						return 'include ' + filepath.replace(/.jade^/gi, '');
					}
				}))
				.pipe(gulp.dest(globs.views.inject.where));
		},
		compileStatic: function() {
			var merged = merge();

			// first, use the first (default) language for the default destination
			merged.add(gulp.src(globs.views.compile)
					   .pipe(plugins.plumber())
					   .pipe(plugins.jade({
						   jade: require('jade-latte')(require('jade')),
						   locals: templateLocals,
						   pretty: true
					   }))
					   .pipe(plugins.flatten())
					   .pipe(gulp.dest(globs.views.dest))
					   .on('error', plugins.util.log));

			// ...then compile each language into a separate folder
			for (var i = 0, l = tr.languages.length; i < l; i++) {
				var lang = tr.languages[i];
				var dest = path.join(globs.views.dest, lang)
				var translations = R.map(R.prop(lang), tr.keys)
				//var locals = {...templateLocals, ...{tr: translations}}
				var locals = Object.assign({}, templateLocals, {
					tr: translations,
					lang: lang
				})

				merged.add(gulp.src(globs.views.compile)
						   .pipe(plugins.plumber())
						   .pipe(plugins.jade({
							   jade: require('jade-latte')(require('jade')),
							   locals: locals,
							   pretty: true
						   }))
						   .pipe(plugins.flatten())
						   //.pipe(rename('index_' + lang + '.html'))
						   .pipe(gulp.dest(dest))
						   .on('error', plugins.util.log));
			}

			// return all streams combined
			return merged;
		}
	};
};
