module.exports = function(gulp, plugins, globs, project_info, scripts_entry, views_entry, browserSync) {

    var fse = require('fs-extra');
    var path = require('path');
    var run_sequence = require('run-sequence');
    var release = process.argv.indexOf('--release') !== -1;
    var views = views_entry;
    var _ = require('lodash');


    // pokud je v feds.json property content a je to objekt, zkusím načíst JSONy, které definuje
    if (typeof _.get(project_info, 'content', undefined) === 'object') {
        _.each(project_info.content, function(file, key) {
            file = path.join(process.cwd(), file);
            var data = fse.readJsonSync(file, {throws: false});
            _.set(project_info.content, key, data);
        });
    }

    var templateLocals = {
        pkg: fse.readJsonSync(path.join(process.cwd(), 'package.json')),
        content: _.get(project_info, 'content', fse.readJsonSync(path.join(process.cwd(), 'content.json')))
    };

    return {
        inject: function() {
            var files_to_inject = gulp.src(globs.views.inject.what, {
                read: false
            });

            return gulp.src(path.join(globs.views.inject.where, 'injected.jade'))
                .pipe(plugins.inject(files_to_inject, {
                    starttag: '//- inject:{{ext}}',
                    endtag: '//- endinject',
                    relative: true,
                    transform: function(filepath) {
                        return 'include ' + filepath.replace(/.jade^/gi, '');
                    }
                }))
                .pipe(gulp.dest(globs.views.inject.where));
        },
        compileStatic: function() {
            return gulp.src(globs.views.compile)
                .pipe(plugins.plumber())
                .pipe(plugins.jade({
                    jade: require('jade-latte')(require('jade')),
                    locals: templateLocals,
                    pretty: true
                }))
                .pipe(plugins.flatten())
                .pipe(gulp.dest(globs.views.dest))
                .on('error', plugins.util.log);
        },
        compileDynamic: function() {
            var tasks = [];
            views.list.forEach(function(item, index) {

                var srcPath = path.join(process.cwd(), project_info.sources.pages, item.src + '.jade');
                var destDir = path.join(process.cwd(), path.dirname(item.dest));
                var destFile = path.basename(item.dest);
                var destExt = '.' + ('ext' in item ? item.ext : 'tpl');

                gulp.src(srcPath)
                    .pipe(plugins.plumber())
                    .pipe(plugins.jade({
                        jade: require('jade-latte')(require('jade')),
                        locals: templateLocals,
                        pretty: true
                    }))
                    // .pipe(plugins.if(!project_info.bemTransform, plugins.posthtml([require('posthtml-bem')({
                    //     elemPrefix: '__',
                    //     modPrefix: '_',
                    //     modDlmtr: '--'
                    // })])))
                    .pipe(plugins.rename({
                        basename: destFile,
                        extname: destExt
                    }))
                    .pipe(gulp.dest(destDir))
                    .on('error', plugins.util.log);
            });

            return tasks;
        }
    };

};
