module.exports = function(_gulp, plugins, globs, project_info, scripts_entry, views_entry, browserSync) {
    var path = require('path'),
        release = process.argv.indexOf('--release') !== -1,
        throttle = require('lodash.throttle'),
        run_sequence = require('run-sequence');

    return function(gulp) {
        return function() {
            gulp.watch(globs.styles.watch, {
                debounceDelay: 200
            }, function(e) {
                // On file changed
                if (e.type === 'changed') {
                    gulp.start('styles', browserSync.reload);
                }

                // On file added
                if (e.type === 'added') {
                    gulp.start('styles.compile', browserSync.reload);
                }
            });

            gulp.watch(globs.views.watch, {
                debounceDelay: 200
            }, function(e) {
                // On file changed
                if (e.type === 'changed') {
                    if (project_info.settings.views === 'static') {
                        gulp.start('views.compile.static', browserSync.reload);
                    } else {
                        gulp.start('views.compile.dynamic', browserSync.reload);
                    }
                }

                // On file added
                if (e.type === 'added') {
                    run_sequence('views.inject', ['views.compile.static', 'views.compile.dynamic'], browserSync.reload);
                }

            });

            gulp.watch([process.cwd() + '/app/**/*.md'], {
                debounceDelay: 200
            }, function(e) {
                // On file changed
                if (e.type === 'changed') {
                    gulp.start('docs');
                }

                // On file added
                if (e.type === 'added') {
                    gulp.start('docs');
                }

            });

            gulp.watch(globs.images.watch, {
                debounceDelay: 200
            }, ['images'], browserSync.reload);

            gulp.watch(globs.assets.fonts.what, {
                debounceDelay: 200
            }, ['assets-fonts'], browserSync.reload);

            gulp.watch(globs.assets.public.what, {
                debounceDelay: 200
            }, ['assets-public'], browserSync.reload);

            gulp.watch(globs.scripts.watch, function(e) {
                // On file changed
                if (e.type === 'changed') {
                    gulp.start('scripts.webpack', browserSync.reload);
                }

                // On file added
                if (e.type === 'added') {
                    run_sequence('scripts.inject', ['scripts.webpack'], browserSync.reload);
                }
            });

            var siteUrl = project_info.siteUrlDevelopment || 'devel' + path.join(process.cwd().replace('/mnt/www', ''), project_info.destinations.base_dir);
            var bsSettings = project_info.browserSyncSettings || {
                reloadDebounce: 2500,
                port: globs.ports.static_server,
                ui: {
                    port: globs.ports.ui,
                },
                proxy: {
                    target: siteUrl,
                },
                host: '192.168.2.6',
                // server: {
                //  baseDir: "../www",
                //  directory: true
                // }
            };

            browserSync.init(bsSettings);

        };
    };
};
